@@ -30,19 +30,21 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
-#include "xst.h"
+#include "gst.h"
 #include "boot-image.h"
 #include "table.h"
 
-extern XstTool *tool;
+extern GstTool *tool;
 
-static XstBootImageTypeTable boot_image_type_table[] = {
+static GstBootImageTypeTable boot_image_type_table[] = {
 	{ N_("Unknown"),    TYPE_UNKNOWN },
 	{ N_("Windows NT"), TYPE_WINNT },
 	{ N_("Windows 9x"), TYPE_WIN9X },
 	{ N_("Dos"),        TYPE_DOS },
 	{ N_("Linux"),      TYPE_LINUX },
-	{ NULL,             -1 }	
+	{ N_("Linux swap"), TYPE_LINSWAP },
+	{ N_("GNU/Hurd"),   TYPE_HURD },
+	{ NULL,             -1 }
 };
 
 gint
@@ -53,9 +55,9 @@ boot_image_count (xmlNodePtr root)
 
 	g_return_val_if_fail (root != NULL, -1);
 	
-	for (count = 0, n = xst_xml_element_find_first (root, "entry");
+	for (count = 0, n = gst_xml_element_find_first (root, "entry");
 	     n != NULL;
-	     count++, n = xst_xml_element_find_next (n, "entry"));
+	     count++, n = gst_xml_element_find_next (n, "entry"));
 
 	return count;
 }
@@ -67,7 +69,7 @@ boot_image_new (void)
 	guint      count;
 	xmlNodePtr root;
 
-	root = xst_xml_doc_get_root (tool->config);
+	root = gst_xml_doc_get_root (tool->config);
 	
 	count = boot_image_count (root);
 	if (count >= MAX_IMAGES || count < 0)
@@ -94,14 +96,24 @@ boot_image_get_by_node (xmlNodePtr node)
 
 	image->type = boot_value_type (node);
 	image->label = boot_value_label (node);		
-	image->is_default = boot_value_default_as_boolean (node);
+	image->is_default = boot_value_default (node);
 	
 	if (image->type == TYPE_LINUX) {
 		image->image = boot_value_image (node, TRUE);
 		image->root = boot_value_root (node);
 		image->append = boot_value_append (node);
-	} else
+		image->initrd = boot_value_initrd (node);
+	}
+	else if (image->type == TYPE_HURD) {
+		image->image = boot_value_image (node, TRUE);
+		image->root = boot_value_root (node);
+		image->append = boot_value_append (node);
+		image->module = boot_value_module (node);
+	}
+	else
 		image->image = boot_value_device (node, TRUE);
+
+	image->password = boot_value_password (node);
 	
 	return image;
 }
@@ -114,10 +126,10 @@ get_new_key (xmlNodePtr root)
 	gint maxkey, keynum;
 
 	maxkey = 0;
-	for (node = xst_xml_element_find_first (root, "entry");
-	     node; node = xst_xml_element_find_next (node, "entry"))
+	for (node = gst_xml_element_find_first (root, "entry");
+	     node; node = gst_xml_element_find_next (node, "entry"))
 	{
-		key = xst_xml_get_child_content (node, "key");
+		key = gst_xml_get_child_content (node, "key");
 		if (key) {
 			keynum = atoi (key);
 			if (maxkey <= keynum)
@@ -125,7 +137,7 @@ get_new_key (xmlNodePtr root)
 			g_free (key);
 		} else
 			/* This leaks, but it's not supposed to happen in production. */
-			g_warning ("Entry %s has no key.", xst_xml_get_child_content (node, "label"));
+			g_warning ("Entry %s has no key.", gst_xml_get_child_content (node, "label"));
 	}
 
 	return g_strdup_printf ("%d", maxkey);
@@ -159,23 +171,26 @@ boot_image_save (BootImage *image)
 	boot_value_set_image (node, image->image, image->type);
 	boot_value_set_root (node, image->root);
 	boot_value_set_append (node, image->append);
+	boot_value_set_initrd (node, image->initrd);
+	boot_value_set_password (node, image->password);
 }
 
 void
 boot_image_destroy (BootImage *image)
 {
 	if (image) {
-		if (image->label)  g_free (image->label);
-		if (image->image)  g_free (image->image);
-		if (image->root)   g_free (image->root);
-		if (image->append) g_free (image->append);
+		if (image->label)    g_free (image->label);
+		if (image->image)    g_free (image->image);
+		if (image->root)     g_free (image->root);
+		if (image->append)   g_free (image->append);
+		if (image->initrd)   g_free (image->initrd);
+		if (image->password) g_free (image->password);
 	
 		g_free (image);
 	}
 }
 
 /* Checking functions */
-
 static gboolean
 boot_image_valid_name_chars (const gchar *string)
 {
@@ -184,14 +199,14 @@ boot_image_valid_name_chars (const gchar *string)
 	gchar *value;
 	gboolean res;
 	
-	doc = xst_tool_run_get_directive (tool, NULL, "verify", "entrylabel", string, NULL);
-	root = xst_xml_doc_get_root (doc);
+	doc = gst_tool_run_get_directive (tool, NULL, "verify", "entrylabel", string, NULL);
+	root = gst_xml_doc_get_root (doc);
 
-	value = xst_xml_get_child_content (root, "result");
+	value = gst_xml_get_child_content (root, "result");
 	res =  (strcmp (value, "success"))? FALSE: TRUE;
 
 	g_free (value);
-	xst_xml_doc_destroy (doc);
+	gst_xml_doc_destroy (doc);
 	
 	return res;
 }
@@ -228,14 +243,14 @@ boot_image_label_exists (BootImage *image)
 	else
 		root = image->node->parent;
 
-	for (node = xst_xml_element_find_first (root, "entry");
+	for (node = gst_xml_element_find_first (root, "entry");
 	     node != NULL;
-	     node = xst_xml_element_find_next (node, "entry")) {
+	     node = gst_xml_element_find_next (node, "entry")) {
 
 		if (node == image->node)
 			continue;
 
-		buf = xst_xml_get_child_content (node, "label");
+		buf = gst_xml_get_child_content (node, "label");
 		if (buf) {
 			if (strcmp (buf, image->label) == 0) {
 				found = TRUE;
@@ -258,7 +273,7 @@ boot_image_file_exists (const gchar *string)
 
 	if (stat (string, &s)) {
 		if (errno) {
-			error = g_strdup_printf (_("Invalid path: %s"), string);
+			error = g_strdup_printf (_("\"%s\" is an invalid path"), string);
 		}
 	}
 
@@ -274,17 +289,15 @@ boot_image_valid_label (BootImage *image)
 		return NULL;
 
 	if (boot_image_label_exists (image)) {
-		error = g_strdup_printf (_("Image '%s' already exists, please set another name."),
+		error = g_strdup_printf (_("\"%s\" already exists, please set another name"),
 					 image->label);
 		return error;
 	}
 	
 	if (!boot_image_valid_name_chars (image->label)) {
-		error = g_strdup_printf (_("Invalid image name: '%s'"), image->label);
+		error = g_strdup_printf (_("Invalid image name: \"%s\""), image->label);
 		return error;
 	}
-
-
 	
 	return error;
 }
@@ -295,7 +308,7 @@ boot_image_valid_device (BootImage *image)
 	gchar *error = NULL;
 
 	if (!boot_image_valid_chars (image->image)) {
-		error = g_strdup_printf (_("Invalid image: '%s'"), image->image);
+		error = g_strdup_printf (_("Invalid image: \"%s\""), image->image);
 		return error;
 	}
 
@@ -313,7 +326,7 @@ boot_image_valid_root (BootImage *image)
 		return NULL; /* Not required */
 	
 	if (!boot_image_valid_chars (image->root)) {
-		error = g_strdup_printf (_("Invalid root device: '%s'"), image->root);
+		error = g_strdup_printf (_("Invalid root device: \"%s\""), image->root);
 		return error;
 	}
 
@@ -322,6 +335,24 @@ boot_image_valid_root (BootImage *image)
 	return error;
 }
 
+gchar *
+boot_image_valid_initrd (BootImage *image)
+{
+	if (image->initrd == NULL || strlen (image->initrd) == 0)
+		return NULL;
+
+	return boot_image_file_exists (image->initrd);
+}
+
+gchar *
+boot_image_valid_module (BootImage *image)
+{
+	if (image->module == NULL || strlen (image->module) == 0)
+		return NULL;
+
+	return boot_image_file_exists (image->module);
+}
+
 gchar *
 boot_image_check (BootImage *image)
 {
@@ -339,6 +370,10 @@ boot_image_check (BootImage *image)
 	if (error)
 		return error;
 
+	error = boot_image_valid_initrd (image);
+	if (error)
+		return error;
+
 	/* everything is fine, no errors */
 	return NULL;
 }
@@ -346,28 +381,27 @@ boot_image_check (BootImage *image)
 /* Helpers */
 
 gchar *
-type_to_label (XstBootImageType type)
+type_to_label (GstBootImageType type)
 {
 	gint i;
 
 	for (i = 0; boot_image_type_table[i].label; i++)
 		if (type == boot_image_type_table[i].type)
-			return g_strdup (boot_image_type_table[i].label);
+			return _(boot_image_type_table[i].label);
 
 	g_warning ("type_to_label: unknown type.");
-	return g_strdup ("");
+	return _(boot_image_type_table[0].label);
 }
 
-XstBootImageType
+GstBootImageType
 label_to_type (const gchar *label)
 {
 	gint i;
 
 	for (i = 0; boot_image_type_table[i].label; i++)
-		if (!strcmp (label, boot_image_type_table[i].label))
+		if (strcmp (label, boot_image_type_table[i].label) == 0)
 			return boot_image_type_table[i].type;
 
-	g_warning ("label_to_type: unknown label '%s'.", label);
 	return TYPE_UNKNOWN;
 }
 
@@ -382,3 +416,4 @@ type_labels_list (void)
 	
 	return list;
 }
+
