@@ -159,17 +159,18 @@ gst_auth_get_auth_required (GstTool *tool)
 {
 	const gchar  *answer = "yes\n";
 	gboolean      cont   = FALSE;
-	gchar        *str;
+	gchar        *s, *str;
 	gint          ret;
 
 	while (!cont) {
-		str = gst_tool_read_from_backend (tool, "assword:", "/no)?", "\n", NULL);
+		s   = gst_tool_read_from_backend (tool, "assword:", "/no)?", "\n", NULL);
+		str = g_ascii_strup (s, -1);
 
 		/* FIXME: hope that someday we can get rid of this ssh output string parsing */
-		if (g_strrstr (g_ascii_strup (str, -1), "AUTHENTICITY") != NULL) {
+		if (g_strrstr (str, "AUTHENTICITY") != NULL) {
 			/* it's the "add to known hosts list" ssh's message, just answer "yes" */
 			gst_tool_write_to_backend (tool, (gchar *) answer);
-		} else if (g_strrstr (g_ascii_strup (str, -1), "PASSWORD") != NULL) {
+		} else if (g_strrstr (str, "PASSWORD") != NULL) {
 			/* it's asking for the password */
 			cont = TRUE;
 			ret  = GST_AUTH_PASSWORD;
@@ -180,6 +181,7 @@ gst_auth_get_auth_required (GstTool *tool)
 			ret  = GST_AUTH_PASSWORDLESS;
 		}
 
+		g_free (s);
 		g_free (str);
 	}
 
@@ -300,14 +302,16 @@ gst_auth_save_locale (GString* command) {
 	lc_all      = getenv ("LC_ALL");
 	lang        = getenv ("LANG");
 
+	g_string_append (command, "env ");
+
 	if (lc_all)
-		g_string_append_printf (command, "export LC_ALL=\"%s\" && ", lc_all);
-	else if (lc_messages)
-		g_string_append_printf (command, "export LC_MESSAGES=\"%s\" && ", lc_messages);
-	else if (lang)
-		g_string_append_printf (command, "export LANG=\"%s\" && ", lang);
-	else if (language)
-		g_string_append_printf (command, "export LANGUAGE=\"%s\" && ", language);
+		g_string_append_printf (command, "LC_ALL=\"%s\" ", lc_all);
+	if (lc_messages)
+		g_string_append_printf (command, "LC_MESSAGES=\"%s\" ", lc_messages);
+	if (lang)
+		g_string_append_printf (command, "LANG=\"%s\" ", lang);
+	if (language)
+		g_string_append_printf (command, "LANGUAGE=\"%s\" ", language);
 }
 
 void
